# pkg-perl/module-name -- lintian check script for checking that module name is present in the long description
#
# Copyright © 2013 Niels Thykier <niels@thykier.net>
# Copyright © 2013 gregor herrmann <gregoa@debian.org>
# Copyright © 2013 Axel Beckert <abe@debian.org>
# Copyright © 2014 Damyan Ivanov <dmn@debian.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::pkg_perl::module_name;

use strict;
use warnings;

use Lintian::Tags qw(tag);

sub run {
    my ( $pkg, $type, $info, $proc, $group ) = @_;

    # Only for pkg-perl packages
    return
        unless $info->field('maintainer')
        =~ /pkg-perl-maintainers\@lists\.alioth\.debian\.org/sm;

    my @binaries = $info->binaries;
    for my $b (@binaries) {
        next unless $b =~ /lib(.+)-perl/;
        my $mod = $1;
        $mod = join( '::', map {ucfirst} split( /-/, $mod ) );
        my $mod_lc = lc($mod);
        my $d = $info->binary_field( $b, 'description' );
        $d =~ s/[^\n]+\n//; # strip long description

        tag( 'no-module-name-in-description', $b, $mod )
            unless lc($d) =~ /\Q$mod_lc\E/;
    }
}

1;
